about summary refs log tree commit diff
path: root/tvix/store/src/fs/inodes.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tvix/store/src/fs/inodes.rs')
-rw-r--r--tvix/store/src/fs/inodes.rs42
1 files changed, 22 insertions, 20 deletions
diff --git a/tvix/store/src/fs/inodes.rs b/tvix/store/src/fs/inodes.rs
index e8959ce362..928f510590 100644
--- a/tvix/store/src/fs/inodes.rs
+++ b/tvix/store/src/fs/inodes.rs
@@ -1,6 +1,7 @@
 //! This module contains all the data structures used to track information
 //! about inodes, which present tvix-store nodes in a filesystem.
-use crate::{proto, B3Digest};
+use tvix_castore::proto as castorepb;
+use tvix_castore::B3Digest;
 
 #[derive(Clone, Debug)]
 pub enum InodeData {
@@ -10,33 +11,33 @@ pub enum InodeData {
 }
 
 /// This encodes the two different states of [InodeData::Directory].
 /// Either the data still is sparse (we only saw a [proto::DirectoryNode], but
 /// didn't fetch the [proto::Directory] struct yet,
 /// or we processed a lookup and did fetch the data.
 #[derive(Clone, Debug)]
 pub enum DirectoryInodeData {
-    Sparse(B3Digest, u32),                              // digest, size
-    Populated(B3Digest, Vec<(u64, proto::node::Node)>), // [(child_inode, node)]
+    Sparse(B3Digest, u32),                                  // digest, size
+    Populated(B3Digest, Vec<(u64, castorepb::node::Node)>), // [(child_inode, node)]
 }
 
-impl From<&proto::node::Node> for InodeData {
-    fn from(value: &proto::node::Node) -> Self {
+impl From<&castorepb::node::Node> for InodeData {
+    fn from(value: &castorepb::node::Node) -> Self {
         match value {
-            proto::node::Node::Directory(directory_node) => directory_node.into(),
-            proto::node::Node::File(file_node) => file_node.into(),
-            proto::node::Node::Symlink(symlink_node) => symlink_node.into(),
+            castorepb::node::Node::Directory(directory_node) => directory_node.into(),
+            castorepb::node::Node::File(file_node) => file_node.into(),
+            castorepb::node::Node::Symlink(symlink_node) => symlink_node.into(),
         }
     }
 }
 
-impl From<&proto::SymlinkNode> for InodeData {
-    fn from(value: &proto::SymlinkNode) -> Self {
+impl From<&castorepb::SymlinkNode> for InodeData {
+    fn from(value: &castorepb::SymlinkNode) -> Self {
         InodeData::Symlink(value.target.clone())
     }
 }
 
-impl From<&proto::FileNode> for InodeData {
-    fn from(value: &proto::FileNode) -> Self {
+impl From<&castorepb::FileNode> for InodeData {
+    fn from(value: &castorepb::FileNode) -> Self {
         InodeData::Regular(
             value.digest.clone().try_into().unwrap(),
             value.size,
@@ -46,8 +47,8 @@ impl From<&proto::FileNode> for InodeData {
 }
 
 /// Converts a DirectoryNode to a sparsely populated InodeData::Directory.
-impl From<&proto::DirectoryNode> for InodeData {
-    fn from(value: &proto::DirectoryNode) -> Self {
+impl From<&castorepb::DirectoryNode> for InodeData {
+    fn from(value: &castorepb::DirectoryNode) -> Self {
         InodeData::Directory(DirectoryInodeData::Sparse(
             value.digest.clone().try_into().unwrap(),
             value.size,
@@ -57,11 +58,12 @@ impl From<&proto::DirectoryNode> for InodeData {
 
 /// converts a proto::Directory to a InodeData::Directory(DirectoryInodeData::Populated(..)).
 /// The inodes for each child are 0, because it's up to the InodeTracker to allocate them.
-impl From<proto::Directory> for InodeData {
-    fn from(value: proto::Directory) -> Self {
+impl From<castorepb::Directory> for InodeData {
+    fn from(value: castorepb::Directory) -> Self {
         let digest = value.digest();
 
-        let children: Vec<(u64, proto::node::Node)> = value.nodes().map(|node| (0, node)).collect();
+        let children: Vec<(u64, castorepb::node::Node)> =
+            value.nodes().map(|node| (0, node)).collect();
 
         InodeData::Directory(DirectoryInodeData::Populated(digest, children))
     }
@@ -10,33 +11,33 @@ pub enum InodeData {
 
 /// This encodes the two different states of [InodeData::Directory].
-/// Either the data still is sparse (we only saw a [proto::DirectoryNode], but
-/// didn't fetch the [proto::Directory] struct yet,
-/// or we processed a lookup and did fetch the data.
+/// Either the data still is sparse (we only saw a [castorepb::DirectoryNode],
+/// but didn't fetch the [castorepb::Directory] struct yet, or we processed a
+/// lookup and did fetch the data.
 #[derive(Clone, Debug)]
 pub enum DirectoryInodeData {